@@ -50,24 +50,20 @@ plotind <- structure(function#Plot indicator
      }
     
 } , ex=function(){
-    ## Warnings from GDAL/PROJ are suppressed.
-
     ## RasterBrick of structural Essential Biodiversity Variables
     ## covering the extent of a location in the northern Amazon basin
     ## (Colombia) is imported:
     path. <- system.file('amazon.grd',package = 'ecochange')
-    amazon <- suppressWarnings(brick(path.))
+    amazon <- brick(path.)
     
     ## Changes in layers of tree-canopy cover (TC) in the 'amazon'
     ## brick are computed:
-    suppressWarnings(
     def <- echanges(amazon, eco = 'TC',
                     change = 'lossyear',
                     eco_range = c(1,80),
                     get_unaffected = TRUE,
                     binary_output = FALSE,
                     mc.cores = 2)
-    )
     
     ## Function 'gaugeIndicator' is used to compute ecosystem areas
     ## (default metric of the function):
