@@ -39,8 +39,8 @@ rsp2ebv <- structure(function#Integrate remote sensing products
                       ##agencies must forge a global monitoring
                       ##strategy. Nature, 523(7561), 403-406.}
 
-                     
-                     
+
+
 (
     ps = NULL, ##<<\code{SpatialPolygonsDataFrame}; or
                 ##\code{character}; or \code{NULL}. Region of
@@ -49,15 +49,15 @@ rsp2ebv <- structure(function#Integrate remote sensing products
                 ##\code{\link{getGADM}}); or 3) a \code{NULL}
                 ##value. Default \code{NULL} makes the function to
                 ##print a list of \code{GADM} units.
-    ..., ##<<If \code{ps} is a \code{GADM} unit then additional
-         ##arguments in \code{\link{getGADM}} can be specified here.
-    lyrs = NULL, ##<<\code{character}. Names of the ecosystem
-                 ##earth-observation products. If \code{NULL} then a
-                 ##list of products is printed, see
-                 ##\code{\link{listGP}}.  Default \code{NULL}.
+    ..., ##<<Additional arguments in \code{\link{getGADM}} and
+         ##\code{\link{getrsp}}.
+    lyrs = NULL, ##<<\code{character}. Remote-sensing
+                ##products. Default \code{NULL} makes the function to
+                ##print a list of Downloadable data, see
+                ##\code{\link{listGP}}.
     path, ##<<\code{character}. Path name indicating where the
           ## variables are stored. If missing then a folder
-          ## named as \code{'ecochange'} located in a current
+          ## named as \code{'ecochange'} created in a current
           ## temporary directory is used.
     sr, ##<< \code{character}. \code{PROJ.4} description of the target
         ##coordinate reference system. If missing then the target
@@ -71,21 +71,18 @@ rsp2ebv <- structure(function#Integrate remote sensing products
                                           ##the cores.
 
 ) {
-    # unlink(file.path(path,'ebv'), recursive = TRUE)
-    # unlink(file.path(path,'ecochange'), recursive = TRUE)
-    
     if(missing(path)){
-        ecodir <- file.path(tempdir(),'ecochange')
+        ecodir <- normalizePath(file.path(tempdir(),'ecochange'),
+                                winslash = '/',mustWork = FALSE)
         if(!file.exists(ecodir))
-        dir.create(ecodir)
+            dir.create(ecodir)
         path  <- ecodir}
-
-    if(!getOption('gdal_path')){
-        print('invalid GDAL install')
-        return(FALSE)
-    }
-
-    
+    if(!missing(path))
+        path <- normalizePath(path.expand(path), winslash = '/',mustWork = FALSE)
+    ## if(!getOption('gdal_path')){
+    ##     print('invalid GDAL install')
+    ##     return(FALSE)
+    ## }
     if(inherits(ps, getOption('inh')[c(1,3:4)])){
         ps. <- ps
         ps <- getrsp(ps, ...,lyrs = lyrs, path = path, mc.cores = mc.cores)
@@ -93,40 +90,42 @@ rsp2ebv <- structure(function#Integrate remote sensing products
             return(ps)
         if(is.null(lyrs))
             return(ps)}
-
     ps <- attributes(ps)$env$roi
-    
     if(is.null(lyrs))return(listGP()$'layer')
     if(any(grepl('.01.01', lyrs))){
         lyrs <- rnm.lyrs0(lyrs)}
     int.patt  <- '[[:digit:]|N|S|E|W].tif'
-    zfe <- file.path(path, dir(path))
+    zfe <- normalizePath(file.path(path, dir(path)), winslash = '/', mustWork = FALSE)
     dec <- zfe
     with_zip <- any(grepl(paste(lyrs, collapse = "|"), zfe)&grepl('.zip', zfe))
     if(with_zip){
-    dec <- decompMap0(zfe, td = path, int.patt = int.patt)
-    tor <- attr(dec,'inzip')}
+        dec <- decompMap0(zfe, td = path, int.patt = int.patt)
+        tor <- attr(dec,'inzip')}
     dec <- sort(dec[grepl(paste(lyrs, collapse = "|"), dec)])
     rst <- Map(function(x)
         tryCatch(raster(x),error = function(e){
             print(NULL)}), x = dec)
+    ## ftr <- function(ps, z){
+    ##     lapply(z, function(x)
+    ##         spTransform(ps, CRSobj = crs(x)))}
     ftr <- function(ps, z){
-        lapply(z, function(x)
-            spTransform(ps, CRSobj = crs(x)))}
+        lapply(z, function(x){
+        ## clsss <- class(ps)
+        ps <- st_as_sf(ps)
+        ps <- st_transform(ps, crs = crs(x))
+        ps <- as(ps, "Spatial")})}
     et <- ftr(ps,rst)
-
     trs. <- Map(function(x,y)
         raster::intersect(extent(x),extent(y)),rst, et)
     trs <- names(Filter(function(x)
         !is.null(x),trs.))
     rst <- raster::subset(rst,names(rst)%in%trs)
     et <- et[trs]
-    
     cr <- rst
-    
     if(missing(sr)){
-        l2u <- long2UTM(extent(ps)[1L])
-        sr <- sub('utm.z',l2u, getOption('utm1'))}
+    l2u <- long2UTM(extent(ps)[1L])
+    sr <- sub('utm.z',l2u, getOption('utm1'))
+    }
     fext <- function(ps, tmp, sr){
         pr <- lapply(tmp, function(x)
             projectExtent(x, sr))
@@ -138,101 +137,113 @@ rsp2ebv <- structure(function#Integrate remote sensing products
     nex <- as.vector(uxt)
     te. <- nex[c(1,3,2,4)]
     flnm <- 'ebv'
-        unlink(file.path(tempdir(), flnm), recursive = TRUE)
-        dir.create(file.path(tempdir(),flnm))
-
-    nwp <- file.path(tempdir(), flnm)
-    
-    gdf <- names(cr)
-
-    nwp. <- file.path(tempdir(), flnm, basename(gdf))
-
-        nmdst <- '250' ## <- preserves zero values
-
+    nwp <- normalizePath(file.path(tempdir(), flnm), winslash = '/', mustWork = FALSE)
+    dir.create(nwp, showWarnings=FALSE)
+    gdf <- normalizePath(names(cr), winslash = '/', mustWork = FALSE)
+    nwp. <- normalizePath(file.path(nwp,basename(gdf)),winslash = '/', mustWork = FALSE)
+    nmdst <- '250' ## <- preserves zero values
     fshp <- function(x,y){
         fname <- file.path(tempdir(),paste0(basename(y),'.shp'))
         raster::shapefile(x, filename = fname,
                           overwrite = TRUE)
-        return(fname)
-    }
-    
+        return(fname)}
     sps <- Map(function(x,y)
         fshp(x, y), et, names(et))
+    sps <- lapply(sps, function(x)
+        normalizePath(x, winslash = '/', mustWork = FALSE))
+    ## return(list(gdf = gdf, nwp. = nwp.,nwp = nwp,sps = sps, cr = cr, sr = sr, ofr = ofr, nmdst = nmdst, te. = te.))
 
     marg. <- c(list(FUN = function(x,y,z,w)
-        gdalUtils::gdalwarp(srcfile = x,
-                            dstfile = y, crs(z),
-                            sr, te = te., tr = ofr,
-                            crop_to_cutline = TRUE,
-                            cutline = w,
-                            output_Raster = TRUE,
-                            overwrite=TRUE,
-                            dstnodata = nmdst,
-                            nomd = TRUE),
+        gdalUtilities::gdalwarp(srcfile = x,
+                                dstfile = y, s_srs = proj4string(z),
+                                t_srs = sr, te = te., tr = ofr,
+                                overwrite=TRUE,
+                                crop_to_cutline = TRUE,
+                                cutline = w,
+                                dstnodata = nmdst,
+                                nomd = TRUE),
         x = gdf, y = nwp., z = cr, w = sps), marg)
-    pr <- stack(do.call(getOption('fapp'), marg.))
-
-    fmos <- function(sll){
-        crm <- 'Formatting image'
-        dst <- file.path(nwp,paste0(sll,'.tif'))
-        gdf. <- nwp.[grepl(sll, nwp.)]
-        if(length(gdf.) == 1){
-            mr <- raster(gdf.)}
-        else{
-                mr <- gdalUtils::mosaic_rasters(
-                                     gdalfile=gdf.,
-                                     dst_dataset=dst,
-                                     output_Raster = TRUE)}
-        return(mr)}
+    pr <- unlist(do.call(getOption('fapp'), marg.), use.names = FALSE)
     
+    ## marg. <- c(list(FUN = function(x,y,z,w)
+    ##     gdalUtils::gdalwarp(srcfile = x,
+    ##                         dstfile = y, s_srs = crs(z),
+    ##                         t_srs = sr, te = te., tr = ofr,
+    ##                         crop_to_cutline = TRUE,
+    ##                         cutline = w,
+    ##                         output_Raster = TRUE,
+    ##                         overwrite=TRUE,
+    ##                         dstnodata = nmdst,
+    ##                         nomd = TRUE),
+    ##     x = gdf, y = nwp., z = cr, w = sps), marg)
+    ## pr <- stack(do.call(getOption('fapp'), marg.))
+
+fmos <- function(x){
+    dst <- file.path(nwp,paste0(x,'.tif'))
+    gdf. <- pr[grepl(x, pr)]
+        if(length(gdf.) == 1){
+            mr <- raster(gdf.)
+        }else{
+            mr <- gdalUtilities::gdalwarp(srcfile = gdf.,
+                                          dstfile = dst,
+                                          crop_to_cutline = TRUE,
+                                          overwrite = TRUE)
+            mr <- raster(mr)
+        }
+    return(mr)
+}
+
+    
+    ## fmos <- function(sll){
+    ##     crm <- 'Formatting image'
+    ##     dst <- file.path(nwp,paste0(sll,'.tif'))
+    ##     gdf. <- nwp.[grepl(sll, nwp.)]
+    ##     if(length(gdf.) == 1){
+    ##         mr <- raster(gdf.)}
+    ##     else{
+    ##             mr <- gdalUtils::mosaic_rasters(
+    ##                                  gdalfile=gdf.,
+    ##                                  dst_dataset=dst,
+    ##                                  output_Raster = TRUE)}
+    ##     return(mr)}
+
     marg. <- c(list(FUN = function(x)
         fmos(x), x = lyrs), marg)
     
     temple <- do.call(getOption('fapp'), marg.)
- 
+
+## return(temple)
+        
     if(with_zip){
         file.remove(tor)}
     dr <- dir(path)
     dr1 <- dir(tempdir())
-    
+
     rexp2rem <- '.vrt|.txt|.dbf|.prj|.shp|.shx'
     torem <- file.path(path,dr[grepl(rexp2rem,dr)])
     torem1 <- file.path(tempdir(),dr1[grepl(rexp2rem,dr1)])
     file.remove(c(torem,torem1))
-    temple <- stack(temple)
-return(temple)
+    ## temple <- stack(temple)
+   temple <- brick(temple)
+    return(temple)
+
+
 ### \code{RasterStack} or \code{list}.
 } , ex=function() {
-    ## First, we'll check to make sure there is a valid GDAL
-    ## installation (from 'gdalUtils):
-
-    ## \donttest{
-    ## gdalUtils::gdal_setInstallation()
-    ## valid_install <- !is.null(getOption("gdalUtils_gdalPath"))
-    ## }
-
-    ## Warnings from GDAL/PROJ are suppressed.
-    
     ## A Global Surface Water layer ('seasonality') covering the extent of a
     ## Colombian municipality Cartagena del Chairá is formated into an
     ## spatial EBV:
             load(system.file('cchaira_roi.RData',package = 'ecochange'))
 
     ## \donttest{
-    ## suppressWarnings(
     ## rsp_cchaira <- getrsp(cchaira_roi,
     ##   lyrs = 'seasonality', mc.cores = 2, path = tempdir())
-    ##)
-    
+
     ## file.exists(rsp_cchaira)
 
-    ## suppressWarnings(
     ## season_cchaira <- rsp2ebv(cchaira_roi,
     ##                               lyrs = 'seasonality', path = tempdir())
-    ## )
 
-    ## suppressWarnings(
     ## plotebv(season_cchaira)
-    ## )
     ## }
 })
